@@ -27,8 +27,7 @@
 
 __all__ = ('JSONRPC', 'JSONRPCv1', 'JSONRPCv2', 'JSONRPCLoose',
            'JSONRPCAutoDetect', 'Request', 'Notification', 'Batch',
-           'RPCError', 'FinalRPCError', 'ProtocolError',
-           'JSONRPCConnection', 'handler_invocation')
+           'RPCError', 'ProtocolError', 'JSONRPCConnection', 'handler_invocation')
 
 import itertools
 import json
@@ -143,10 +142,6 @@ class RPCError(CodeMessageError):
         self.cost = cost
 
 
-class FinalRPCError(RPCError):
-    pass
-
-
 class ProtocolError(CodeMessageError):
 
     def __init__(self, code, message):
